@@ -44,12 +44,14 @@
 #include <KIO/JobUiDelegate>
 #include <KIO/RestoreJob>
 #include <KIO/CommandLauncherJob>
+#include <kio_version.h>
 #include <KIO/OpenUrlJob>
 #include <KFileCopyToMenu>
 #include <KJobWidgets>
 #include <KJobUiDelegate>
 #include <KMimeTypeEditor>
 #include <KPluginMetaData>
+#include <KToolInvocation>
 
 #include <QIcon>
 #include <QFileInfo>
@@ -192,14 +194,12 @@ void KonqPopupMenuPrivate::populate()
 
     //check if url is current directory
     if (lstItems.count() == 1) {
-        KFileItem firstPopupItem(lstItems.first());
+        const KFileItem firstPopupItem = lstItems.constFirst();
         if (firstPopupItem.isLink()) {
             isSymLink = true;
             isSymLinkInSameDir = !firstPopupItem.linkDest().contains(QLatin1Char('/'));
         }
-        QUrl firstPopupURL(firstPopupItem.url().adjusted(QUrl::NormalizePathSegments));
-        //qCDebug(LIBKONQ_LOG) << "View path is " << url.url();
-        //qCDebug(LIBKONQ_LOG) << "First popup path is " << firstPopupURL.url();
+        const QUrl firstPopupURL(firstPopupItem.url().adjusted(QUrl::NormalizePathSegments));
         currentDir = (firstPopupURL.matches(url, QUrl::StripTrailingSlash));
         if (firstPopupItem.isDesktopFile()) {
             KDesktopFile desktopFile(firstPopupItem.localPath());
@@ -218,26 +218,13 @@ void KonqPopupMenuPrivate::populate()
     }
 
     const bool isIntoTrash = (url.scheme() == QLatin1String("trash")) && !isCurrentTrash; // trashed file, not trash:/ itself
-
     const bool bIsLink  = (m_popupFlags & KonqPopupMenu::IsLink);
 
-    //qCDebug(LIBKONQ_LOG) << "isLocal=" << isLocal << " url=" << url << " isCurrentTrash=" << isCurrentTrash << " isIntoTrash=" << isIntoTrash << " bTrashIncluded=" << bTrashIncluded;
-
-    //////////////////////////////////////////////////////////////////////////
-
     addGroup(KonqPopupMenu::TopActions); // used e.g. for ShowMenuBar. includes a separator at the end
 
     QAction *act;
-
     QAction *actNewWindow = nullptr;
 
-#if 0 // TODO in the desktop code itself.
-    if ((flags & KonqPopupMenu::ShowProperties) && isOnDesktop &&
-            !KAuthorized::authorizeAction("editable_desktop_icons")) {
-        flags &= ~KonqPopupMenu::ShowProperties; // remove flag
-    }
-#endif
-
     // Either 'newview' is in the actions we're given (probably in the tabhandling group)
     // or we need to insert it ourselves (e.g. for the desktop).
     // In the first case, actNewWindow must remain 0.
@@ -411,7 +398,19 @@ void KonqPopupMenuPrivate::populate()
     }
 
     // Second block, builtin + user
+#if KIO_VERSION < QT_VERSION_CHECK(5, 77, 0)
     m_menuActions.addServiceActionsTo(q);
+#else
+    QList<QAction *> additionalActions;
+    if (isDirectory && m_popupItemProperties.items().count() == 1) {
+        QAction *openTerminalHere = new QAction(QIcon::fromTheme("utilities-terminal"), i18n("Open Terminal Here"), m_parentWidget);
+        QObject::connect(openTerminalHere, &QAction::triggered, q, [this]() {
+            KToolInvocation::invokeTerminal(QString(),  m_popupItemProperties.urlList().constFirst().toLocalFile());
+        });
+        additionalActions << openTerminalHere;
+    }
+    m_menuActions.addActionsTo(q, KFileItemActions::MenuActionSource::Services, additionalActions);
+#endif
 
     q->addSeparator();
 
@@ -458,7 +457,6 @@ void KonqPopupMenuPrivate::populate()
 KonqPopupMenu::~KonqPopupMenu()
 {
     delete d;
-    //qCDebug(LIBKONQ_LOG) << "~KonqPopupMenu leave";
 }
 
 void KonqPopupMenu::setNewFileMenu(KNewFileMenu *newMenu)
