@@ -28,6 +28,7 @@
 #include <kparts/browserextension.h>
 #include <kparts/textextension.h>
 
+#include <kwidgetsaddons_version.h>
 #include <kactioncollection.h>
 #include <QMenu>
 #include <kmessagebox.h>
@@ -51,7 +52,11 @@ PluginBabelFish::PluginBabelFish(QObject *parent,
     m_menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("Translate Web &Page"),
                              actionCollection());
     actionCollection()->addAction(QStringLiteral("translatewebpage"), m_menu);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    m_menu->setPopupMode(QToolButton::InstantPopup);
+#else
     m_menu->setDelayed(false);
+#endif
     connect(m_menu->menu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShow()));
 
