@@ -25,6 +25,7 @@
 #include <QMenu>
 #include <QRegExp>
 
+#include <kwidgetsaddons_version.h>
 #include <kactionmenu.h>
 #include <kservicetypetrader.h>
 #include <klocalizedstring.h>
@@ -50,13 +51,17 @@ K_PLUGIN_FACTORY(UAChangerPluginFactory, registerPlugin<UAChangerPlugin>();)
 UAChangerPlugin::UAChangerPlugin(QObject *parent,
                                  const QVariantList &)
     : KParts::Plugin(parent),
-      m_bSettingsLoaded(false), m_part(0L), m_config(0L)
+      m_bSettingsLoaded(false), m_part(nullptr), m_config(nullptr)
 {
     m_pUAMenu = new KActionMenu(QIcon::fromTheme("preferences-web-browser-identification"),
                                 i18n("Change Browser Identification"),
                                 actionCollection());
     actionCollection()->addAction("changeuseragent", m_pUAMenu);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    m_pUAMenu->setPopupMode(QToolButton::InstantPopup);
+#else
     m_pUAMenu->setDelayed(false);
+#endif
     connect(m_pUAMenu->menu(), &QMenu::aboutToShow, this, &UAChangerPlugin::slotAboutToShow);
 
     if (parent!=nullptr) {
@@ -76,7 +81,7 @@ UAChangerPlugin::~UAChangerPlugin()
 void UAChangerPlugin::slotReloadDescriptions()
 {
     delete m_config;
-    m_config = 0L;
+    m_config = nullptr;
 }
 
 void UAChangerPlugin::parseDescFiles()
